@@ -321,7 +321,7 @@ class RDSClient():
                          model_uri: str):
         """
         """
-        query = f"UPDATE neuralplatform_model SET modelUri = '{model_uri}'' WHERE id = {model_id};"
+        query = f"UPDATE neuralplatform_model SET modelUri = '{model_uri}' WHERE id = {model_id};"
         return self.update_query(query)
     
     def get_version_model(self,
